sdk

package
v1.3.99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 1, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package sdk is the Go SDK for developing ggcode gRPC plugins. This file is at the parent level so users import `sdk` not `sdk/sdk`.

Package sdk is the internal alias for the public SDK. External plugin developers should import: github.com/topcheer/ggcode/sdk/plugin

Index

Constants

This section is empty.

Variables

var MustGetEnv = plugin.MustGetEnv

MustGetEnv re-exports the public MustGetEnv.

var Serve = plugin.Serve

Serve re-exports the public Serve function.

Functions

This section is empty.

Types

type Context

type Context = plugin.Context

Re-export types for internal use.

type Result

type Result = plugin.Result

Re-export types for internal use.

type ResultImage

type ResultImage = plugin.ResultImage

Re-export types for internal use.

type ToolProvider

type ToolProvider = plugin.ToolProvider

Re-export types for internal use.

type ToolSpec

type ToolSpec = plugin.ToolSpec

Re-export types for internal use.

Jump to