package
Version:
v1.1.32
Opens a new window with list of versions in this module.
Published: Apr 14, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Close flushes, closes, and removes all debug log files for the current process.
Init opens the debug log file. Safe to call multiple times.
func Log(pkg, format string, args ...interface{})
Log writes a formatted message with a package tag.
Format: [HH:MM:SS.mmm] [pkg] message
func Logf(format string, args ...interface{})
Logf writes a raw formatted message (no package tag).
Source Files
¶
Click to show internal directories.
Click to hide internal directories.