debug

package
v1.1.31 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Close

func Close()

Close flushes, closes, and removes all debug log files for the current process.

func Init

func Init()

Init opens the debug log file. Safe to call multiple times.

func Log

func Log(pkg, format string, args ...interface{})

Log writes a formatted message with a package tag. Format: [HH:MM:SS.mmm] [pkg] message

func Logf

func Logf(format string, args ...interface{})

Logf writes a raw formatted message (no package tag).

Types

This section is empty.

Jump to