Documentation
¶
Index ¶
Constants ¶
const DefaultProjectMemoryFilename = "GGCODE.md"
Variables ¶
var ProjectMemoryFilenames = []string{
"GGCODE.md",
"AGENTS.md",
"CLAUDE.md",
"COPILOT.md",
}
ProjectMemoryFilenames lists the supported project bootstrap documents in priority order.
Functions ¶
func GenerateProjectMemory ¶
GenerateProjectMemory builds a GGCODE.md document using the current repo state.
func LoadProjectMemory ¶
LoadProjectMemory reads supported project bootstrap documents from global, project root, and subdirectories. Merge order: global -> walked parents -> nested subdirectories.
Types ¶
type AutoMemory ¶
type AutoMemory struct {
// contains filtered or unexported fields
}
AutoMemory manages automatic memory persistence in ~/.ggcode/memory/.
func (*AutoMemory) List ¶
func (am *AutoMemory) List() ([]string, error)
List returns all memory keys.
func (*AutoMemory) LoadAll ¶
func (am *AutoMemory) LoadAll() (string, []string, error)
LoadAll loads all memory files and returns their combined content.
func (*AutoMemory) SaveMemory ¶
func (am *AutoMemory) SaveMemory(key, content string) error
SaveMemory saves a memory entry to ~/.ggcode/memory/{key}.md.
Click to show internal directories.
Click to hide internal directories.